{
  pkgs,
  inputs,
  ...
}: {
  imports = [
    ./apps/firefox.nix
    ./apps/syncthing.nix
  ];

  home.packages = [
    pkgs.pavucontrol
    pkgs.signal-desktop
    pkgs.webcord # pkgs.webcord-vencord
    pkgs.telegram-desktop
    #pkgs.kdePackages.neochat
    pkgs.keepassxc
    #pkgs.blender-hip
    pkgs.buku
    pkgs.libreoffice
    pkgs.darktable
    pkgs.gimp
    pkgs.inkscape
    pkgs.krita
    pkgs.okular
    pkgs.localsend

    pkgs.ffmpeg # Generally useful

    # Music
    #pkgs.feishin # sonixd replacement
    pkgs.supersonic # Music player by Navidrome author
    pkgs.sonixd # Music player; desktop app for Navidrome. Replace w/ Feishin when that supports Subsonic API.
    pkgs.spotube # Use Spotify metadata & user to play from YouTube
    pkgs.spotify # Proprietary
    pkgs.strawberry-qt6 # Fork of Clementine
    pkgs.clementine
    pkgs.lollypop
    # muffon https://muffon.netlify.app/
    pkgs.picard # Edit audio metadata, w/ MusicBrainz integration
    pkgs.puddletag # Edit audio metadata
    pkgs.deadbeef-with-plugins
    # pkgs.tauon
    pkgs.audacious
    # pkgs.asunder # Ripping
    pkgs.cyanrip # Ripping
    # pkgs.whipper # Ripping

    #pkgs.anki # Dep python3.12-pyqt-6.7.0 doesn't build
    pkgs.memento # Japanese

    # Documents
    pkgs.typst # TeX alternative
    pkgs.tinymist # LSP for Typst

    # Dev
    pkgs.vscodium # Consider vscodium-fhs
    #pkgs.jetbrains.rider
    #pkgs.jetbrains.rust-rover
    pkgs.helix
    pkgs.zed-editor

    # Internet
    pkgs.fragments
    pkgs.uget # Download manager
    # From master because PR #290892 is merged but at the time of writing hasn't made it to unstable yet
    # Need it to solve issue #263764
    # https://github.com/NixOS/nixpkgs/issues/263764
    # https://github.com/NixOS/nixpkgs/pull/290892
    # https://github.com/NixOS/nixpkgs/commit/999e0cf59288584616a241c0d8bb7c3c3f1fb417
    pkgs.obsidian
    pkgs.obs-studio
    pkgs.kdePackages.plasmatube
    #pkgs.nyxt

    pkgs.mpvScripts.uosc
    pkgs.mpvScripts.sponsorblock

    pkgs.musescore
    # inputs.muse-sounds-manager.packages.${pkgs.system}.muse-sounds-manager
    pkgs.helio-workstation # music editor
    pkgs.lmms # DAW
    pkgs.carla # VST host
    pkgs.yabridge # Windows VST host
    pkgs.yabridgectl
    pkgs.surge-XT # VST
  ];

  programs.imv.enable = true;

  programs.mangohud = {
    enable = true;
  };

  programs.mpv.enable = true;

  programs.thunderbird = {
    enable = true;
    profiles.default = {
      isDefault = true;
    };
  };

  programs.vscode = {
    enable = true;
    package = pkgs.vscodium;
    enableUpdateCheck = false;
    userSettings = {
      "window.menuBarVisibility" = "toggle";
      "rust-analyzer.server.path" = "rust-analyzer"; # look in env

      # Library sources for rust-analyzer shall be read-only
      "files.readonlyInclude" = {
        "**/.cargo/registry/src/**/*.rs" = true;
        "**/lib/rustlib/src/rust/library/**/*.rs" = true;
      };
    };
    extensions = with pkgs.vscode-extensions; [
      vscodevim.vim
      mkhl.direnv
      jnoortheen.nix-ide
    ];
  };

  programs.zathura.enable = true;
}
